@@ -1,5 +1,5 @@
 from petisco import RabbitMqConnector
-from petisco.event.configurer.infrastructure.rabbitmq_configurer import (
+from petisco.event.configurer.infrastructure.rabbitmq_event_configurer import (
     RabbitMqEventConfigurer,
 )
 from tests.modules.event.mothers.defaults import DEFAULT_ORGANIZATION, DEFAULT_SERVICE
@@ -18,6 +18,13 @@ class RabbitMqEventConfigurerMother:
             connector, DEFAULT_ORGANIZATION, DEFAULT_SERVICE, retry_ttl=10
         )
 
+    @staticmethod
+    def with_service(service: str, connector: RabbitMqConnector = None):
+        connector = RabbitMqConnector() if not connector else connector
+        return RabbitMqEventConfigurer(
+            connector, DEFAULT_ORGANIZATION, service, retry_ttl=10
+        )
+
     @staticmethod
     def with_ttl_1s(connector: RabbitMqConnector = None):
         connector = RabbitMqConnector() if not connector else connector
